@@ -148,6 +148,7 @@ def delete(obj, name):
         tsfile = media.Media(name)
         try:
             tsfile.delete()
+            MEDIA.delete(tsfile.filename + '.ts')
             click.echo('\n{} supprimé'.format(tsfile.filepath))
         except ValueError:
             msg = "Cannot delete {}. It's scheduled for streaming".format(name)
@@ -367,7 +368,7 @@ def check(obj, name, service_id, coherence, send):
                 dst = [
                     "monitoring@gulfsat.mg",
                     "monitoring-tv@blueline.mg",
-                    "admin-tv@gulfsat.mg",
+                    #"admin-tv@gulfsat.mg",
                     "ctv@gulfsat.mg"
                     ]
             else:
@@ -441,7 +442,16 @@ def update(obj, name, service_id):
     """Mise à jour des informations de media ou programme"""
     if obj == 'media':
         if name == 'all':  # on met tout à jour
+            for i in MEDIA.keys():
+                MEDIA.delete(i)
             with click.progressbar(media.Media.all()) as tsfiles:
+                # filenames = []
+                # for tsfile in tsfiles:
+                #     MEDIA.set(tsfile.filename, tsfile.duration)
+                #     filenames.append(tsfile.filename + '.ts')
+                # for i in MEDIA.keys():
+                #     if i not in filenames:
+                #         MEDIA.delete(i)
                 for tsfile in tsfiles:
                     MEDIA.set(tsfile.filename, tsfile.duration)
         else:
