@@ -404,7 +404,7 @@ class Media(object):
                 try:
                     # verifier si c'est un lien symbolink
                     # si oui effacer également la source
-                    source_file = os.readlink(path)
+                    source_file = os.readlink(self.filepath)
                     os.remove(self.filepath)
                     os.remove(source_file)
                 except OSError as err:
